### Name: randtoolbox
### Title: Toolbox for pseudo and quasi random number generation
### Aliases: randtoolbox torus congruRand SFMT setTorusSeed
### Keywords: distribution

### ** Examples

# (1) the Torus algorithm
#
torus(100)

# example of setting the seed
setTorusSeed(1)
torus(5)
setTorusSeed(6)
torus(5)
#the same
setTorusSeed(1)
torus(10)

#no use of the machine time
torus(10, use=FALSE)

#Kolmogorov Smirnov test
#KS statistic should be around 0.0019
ks.test(torus(1000), punif) 
        
#KS statistic should be around 0.0003
ks.test(torus(10000), punif) 

#the mixed Torus sequence
torus(10, mix=TRUE)
par(mfrow = c(1,2))
acf(torus(10^6))
acf(torus(10^6, mix=TRUE))

# (2) the Park Miller sequence
#
# Park Miller sequence, i.e. mod = 2^31-1, mult = 16807, incr=0
# the first 10 seeds used in Park Miller sequence
# 16807          1
# 282475249          2
# 1622650073          3
# 984943658          4
# 1144108930          5
# 470211272          6
# 101027544          7
# 1457850878          8
# 1458777923          9
# 2007237709         10
setTorusSeed(1)
congruRand(10, echo=TRUE)

# the 9998+ th terms 
# 925166085       9998
# 1484786315       9999
# 1043618065      10000
# 1589873406      10001
# 2010798668      10002
setTorusSeed(1614852353) #seed for the 9997th term
congruRand(5, echo=TRUE)

# (3) the SF Mersenne Twister algorithm
SFMT(1000)

#Kolmogorov Smirnov test
#KS statistic should be around 0.037
ks.test(SFMT(1000), punif) 
        
#KS statistic should be around 0.0076
ks.test(SFMT(10000), punif) 


# (4) computation times on my macbook
#
## Not run: 
##D # algorithm                     time in seconds for n=10^6
##D # torus algo                                    0.118 
##D # mixed torus algo                              0.177 
##D # classical mersenne twister            0.139 
##D # SF mersenne twister                   0.084 
##D # park miller                                   0.174 
##D n <- 1e+06
##D mean( rep( system.time( torus(n), gcFirst=TRUE)[3], n) )
##D mean( rep( system.time( torus(n, mixed=TRUE), gcFirst=T)[3], n) )
##D mean( rep( system.time( runif(n), gcFirst=TRUE)[3], n) )
##D mean( rep( system.time( SFMT(n), gcFirst=TRUE)[3], n) )
##D mean( rep( system.time( congruRand(n), gcFirst=TRUE)[3], n) )
##D         
## End(Not run)




